import { Canvas } from "./Canvas.js";
import type { ClickMode } from "../Enums/Modes/ClickMode.js";
import type { Engine } from "./Engine.js";
import type { IContainerInteractivity } from "./Interfaces/IContainerInteractivity.js";
import type { IContainerPlugin } from "./Interfaces/IContainerPlugin.js";
import type { IMovePathGenerator } from "./Interfaces/IMovePathGenerator.js";
import type { IShapeDrawer } from "./Interfaces/IShapeDrawer.js";
import type { ISourceOptions } from "../Types/ISourceOptions.js";
import { Options } from "../Options/Classes/Options.js";
import type { Particle } from "./Particle.js";
import { Particles } from "./Particles.js";
import { Retina } from "./Retina.js";
export declare class Container {
    actualOptions: Options;
    readonly canvas: Canvas;
    destroyed: boolean;
    readonly drawers: Map<string, IShapeDrawer<Particle>>;
    fpsLimit: number;
    readonly id: symbol;
    interactivity: IContainerInteractivity;
    lastFrameTime?: number;
    pageHidden: boolean;
    readonly particles: Particles;
    pathGenerators: Map<string, IMovePathGenerator>;
    readonly plugins: Map<string, IContainerPlugin>;
    responsiveMaxWidth?: number;
    readonly retina: Retina;
    smooth: boolean;
    started: boolean;
    zLayers: number;
    private _currentTheme?;
    private _delay;
    private _delayTimeout?;
    private _drawAnimationFrame?;
    private _duration;
    private readonly _engine;
    private readonly _eventListeners;
    private _firstStart;
    private _initialSourceOptions;
    private readonly _intersectionObserver;
    private _lifeTime;
    private _options;
    private _paused;
    private _sourceOptions;
    constructor(engine: Engine, id: string, sourceOptions?: ISourceOptions);
    get options(): Options;
    get sourceOptions(): ISourceOptions | undefined;
    addClickHandler(callback: (evt: Event, particles?: Particle[]) => void): void;
    addLifeTime(value: number): void;
    addPath(key: string, generator: IMovePathGenerator, override?: boolean): boolean;
    alive(): boolean;
    destroy(): void;
    draw(force: boolean): void;
    export(type: string, options?: Record<string, unknown>): Promise<Blob | undefined>;
    getAnimationStatus(): boolean;
    handleClickMode(mode: ClickMode | string): void;
    init(): Promise<void>;
    loadTheme(name?: string): Promise<void>;
    pause(): void;
    play(force?: boolean): void;
    refresh(): Promise<void>;
    reset(): Promise<void>;
    start(): Promise<void>;
    stop(): void;
    updateActualOptions(): boolean;
    private readonly _intersectionManager;
    private readonly _nextFrame;
}
